Command line utilities reference — IRCO 0.7.1 documentation

# Command line utilities reference

The IRCO packages comes with different command line utilities to work on data sets.

## `irco-convert`

Deprecated.

## `irco-explorer`

Starts the IRCO Explorer server.

## `irco-geolocate`

TODO: This command is not yet ready.

## `irco-graph`

Generate a graph file from a dataset.

## `irco-import`

Import a data set into an IRCO database.

## `irco-init`

Initializes a new IRCO database.